@@ -3,7 +3,7 @@
 *  D e v i c e   C o n t e x t   F o r   W i n d o w s   a n d   I m a g e s    *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1999,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1999,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,17 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXDCWindow.h,v 1.24 2001/08/23 16:24:51 jeroen Exp $                     *
+* $Id: FXDCWindow.h,v 1.38 2004/01/21 07:09:58 fox Exp $                        *
 ********************************************************************************/
 #ifndef FXDCWINDOW_H
 #define FXDCWINDOW_H
 
+#ifndef FXDC_H
+#include "FXDC.h"
+#endif
+
+namespace FX {
+
 
 class FXApp;
 class FXDrawable;
@@ -34,7 +40,6 @@ class FXFont;
 class FXVisual;
 
 
-
 /**
 * Window Device Context
 *
@@ -53,17 +58,17 @@ protected:
   FXuint      flags;          // GC Flags
   FXPixel     devfg;          // Device foreground pixel value
   FXPixel     devbg;          // Device background pixel value
-  void*       gc;             // GC
+  void       *xftDraw;        // Hook used only for XFT support
 #else
   FXID        oldpalette;
   FXID        oldbrush;
   FXID        oldpen;
   FXPixel     devfg;          // Device foreground pixel value
   FXPixel     devbg;          // Device background pixel value
-  FXID        dc;
   FXbool      needsNewBrush;
   FXbool      needsNewPen;
   FXbool      needsPath;
+  FXbool      needsClipReset;
 #endif
 private:
 #ifdef WIN32
@@ -116,6 +121,10 @@ public:
   virtual void fillRectangle(FXint x,FXint y,FXint w,FXint h);
   virtual void fillRectangles(const FXRectangle* rectangles,FXuint nrectangles);
 
+  /// Fill chord
+  virtual void fillChord(FXint x,FXint y,FXint w,FXint h,FXint ang1,FXint ang2);
+  virtual void fillChords(const FXArc* chords,FXuint nchords);
+
   /// Draw arcs
   virtual void fillArc(FXint x,FXint y,FXint w,FXint h,FXint ang1,FXint ang2);
   virtual void fillArcs(const FXArc* arcs,FXuint narcs);
@@ -133,6 +142,9 @@ public:
   /// Draw hashed box
   virtual void drawHashBox(FXint x,FXint y,FXint w,FXint h,FXint b=1);
 
+  /// Draw focus rectangle
+  virtual void drawFocusRectangle(FXint x,FXint y,FXint w,FXint h);
+
   /// Draw area from source
   virtual void drawArea(const FXDrawable* source,FXint sx,FXint sy,FXint sw,FXint sh,FXint dx,FXint dy);
 
@@ -207,7 +219,7 @@ public:
   virtual void clearClipMask();
 
   /// Set font to draw text with
-  virtual void setTextFont(FXFont *fnt);
+  virtual void setFont(FXFont *fnt);
 
   /// Clip against child windows
   virtual void clipChildren(FXbool yes);
@@ -216,5 +228,6 @@ public:
   virtual ~FXDCWindow();
   };
 
+}
 
 #endif
