@@ -3,7 +3,7 @@
 *                        L i s t   B o x   W i d g e t                          *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,17 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXListBox.h,v 1.9 2001/07/17 21:58:56 jeroen Exp $                       *
+* $Id: FXListBox.h,v 1.29 2004/02/08 17:17:33 fox Exp $                         *
 ********************************************************************************/
 #ifndef FXLISTBOX_H
 #define FXLISTBOX_H
 
+#ifndef FXPACKER_H
+#include "FXPacker.h"
+#endif
+
+namespace FX {
+
 
 /// List Box styles
 enum {
@@ -47,20 +53,18 @@ protected:
   FXPopup       *pane;
 protected:
   FXListBox(){}
-  virtual void layout();
 private:
   FXListBox(const FXListBox&);
   FXListBox &operator=(const FXListBox&);
 public:
   long onFocusUp(FXObject*,FXSelector,void*);
   long onFocusDown(FXObject*,FXSelector,void*);
-  long onChanged(FXObject*,FXSelector,void*);
-  long onCommand(FXObject*,FXSelector,void*);
+  long onFocusSelf(FXObject*,FXSelector,void*);
   long onFieldButton(FXObject*,FXSelector,void*);
+  long onListUpdate(FXObject*,FXSelector,void*);
   long onListChanged(FXObject*,FXSelector,void*);
   long onListClicked(FXObject*,FXSelector,void*);
-  long onUpdFmList(FXObject*,FXSelector,void*);
-  long onCmdSetValue(FXObject*,FXSelector,void*);public:
+  long onCmdSetValue(FXObject*,FXSelector,void*);
   long onCmdGetIntValue(FXObject*,FXSelector,void*);
   long onCmdSetIntValue(FXObject*,FXSelector,void*);
 public:
@@ -72,7 +76,7 @@ public:
 public:
 
   /// Constructor
-  FXListBox(FXComposite *p,FXint nvis,FXObject* tgt=NULL,FXSelector sel=0,FXuint opts=FRAME_SUNKEN|FRAME_THICK|LISTBOX_NORMAL,FXint x=0,FXint y=0,FXint w=0,FXint h=0,FXint pl=DEFAULT_PAD,FXint pr=DEFAULT_PAD,FXint pt=DEFAULT_PAD,FXint pb=DEFAULT_PAD);
+  FXListBox(FXComposite *p,FXObject* tgt=NULL,FXSelector sel=0,FXuint opts=FRAME_SUNKEN|FRAME_THICK|LISTBOX_NORMAL,FXint x=0,FXint y=0,FXint w=0,FXint h=0,FXint pl=DEFAULT_PAD,FXint pr=DEFAULT_PAD,FXint pt=DEFAULT_PAD,FXint pb=DEFAULT_PAD);
 
   /// Create server-side resources
   virtual void create();
@@ -83,6 +87,9 @@ public:
   /// Destroy server-side resources
   virtual void destroy();
 
+  /// Perform layout
+  virtual void layout();
+
   /// Enable drive box
   virtual void enable();
 
@@ -114,19 +121,22 @@ public:
   FXint getCurrentItem() const;
 
   /// Return the item at the given index
-  FXString retrieveItem(FXint index) const;
+  FXString getItem(FXint index) const;
 
   /// Replace the item at index
-  void replaceItem(FXint index,const FXString& text,FXIcon* icon=NULL,void* ptr=NULL);
+  FXint setItem(FXint index,const FXString& text,FXIcon* icon=NULL,void* ptr=NULL);
 
   /// Insert a new item at index
-  void insertItem(FXint index,const FXString& text,FXIcon* icon=NULL,void* ptr=NULL);
+  FXint insertItem(FXint index,const FXString& text,FXIcon* icon=NULL,void* ptr=NULL);
 
   /// Add an item to the end of the list
-  void appendItem(const FXString& text,FXIcon* icon=NULL,void* ptr=NULL);
+  FXint appendItem(const FXString& text,FXIcon* icon=NULL,void* ptr=NULL);
 
   /// Prepend an item to the list
-  void prependItem(const FXString& text,FXIcon* icon=NULL,void* ptr=NULL);
+  FXint prependItem(const FXString& text,FXIcon* icon=NULL,void* ptr=NULL);
+
+  /// Move item from oldindex to newindex
+  FXint moveItem(FXint newindex,FXint oldindex);
 
   /// Remove this item from the list
   void removeItem(FXint index);
@@ -134,6 +144,12 @@ public:
   /// Remove all items from the list
   void clearItems();
 
+  /**
+  * Search items for item by name, starting from start item; the
+  * flags argument controls the search direction, and case sensitivity.
+  */
+  FXint findItem(const FXString& text,FXint start=-1,FXuint flags=SEARCH_FORWARD|SEARCH_WRAP) const;
+
   /// Set text for specified item
   void setItemText(FXint index,const FXString& text);
 
@@ -152,6 +168,12 @@ public:
   /// Get data pointer for specified item
   void* getItemData(FXint index) const;
 
+  /// Is the pane shown
+  FXbool isPaneShown() const;
+
+  /// Sort items using current sort function
+  void sortItems();
+
   /// Set text font
   void setFont(FXFont* fnt);
 
@@ -182,6 +204,12 @@ public:
   /// Return selected text color
   FXColor getSelTextColor() const;
 
+  /// Return sort function
+  FXListSortFunc getSortFunc() const;
+
+  /// Change sort function
+  void setSortFunc(FXListSortFunc func);
+
   /// Set the combobox help text
   void setHelpText(const FXString& txt);
 
@@ -204,6 +232,6 @@ public:
   virtual ~FXListBox();
   };
 
-
+}
 
 #endif
