@@ -3,7 +3,7 @@
 *                             P o i n t    C l a s s                            *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1994,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1994,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,12 +19,14 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXPoint.h,v 1.3 2002/01/18 22:42:54 jeroen Exp $                         *
+* $Id: FXPoint.h,v 1.7 2004/02/08 17:17:34 fox Exp $                            *
 ********************************************************************************/
 #ifndef FXPOINT_H
 #define FXPOINT_H
 
 
+namespace FX {
+
 /// Point
 class FXAPI FXPoint {
 public:
@@ -78,5 +80,6 @@ public:
   friend FXAPI FXStream& operator>>(FXStream& store,FXPoint& p);
   };
 
+}
 
 #endif
