@@ -3,7 +3,7 @@
 *                      P r o g r e s s B a r   W i d g e t                      *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXProgressBar.h,v 1.15 2002/01/18 22:42:54 jeroen Exp $                  *
+* $Id: FXProgressBar.h,v 1.20 2004/02/08 17:17:34 fox Exp $                     *
 ********************************************************************************/
 #ifndef FXPROGRESSBAR_H
 #define FXPROGRESSBAR_H
@@ -28,6 +28,7 @@
 #include "FXFrame.h"
 #endif
 
+namespace FX {
 
 
 /// Progress bar styles
@@ -54,6 +55,7 @@ protected:
   FXColor  textAltColor;
 protected:
   FXProgressBar(){}
+  void drawInterior(FXDCWindow& dc);
 private:
   FXProgressBar(const FXProgressBar&);
   FXProgressBar &operator=(const FXProgressBar&);
@@ -152,4 +154,6 @@ public:
   virtual ~FXProgressBar();
   };
 
+}
+
 #endif
