@@ -19,7 +19,7 @@
 * along with this program; if not, write to the Free Software                   *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: PropertyDialog.cpp,v 1.18 2003/02/10 16:50:29 fox Exp $                  *
+* $Id: PropertyDialog.cpp,v 1.19 2004/02/08 17:05:34 fox Exp $                  *
 ********************************************************************************/
 #include "xincs.h"
 #include "fx.h"
@@ -151,7 +151,7 @@ PropertyDialog::PropertyDialog(FXWindow *owner):
   // List of possible extensions of this file type
   FXGroupBox *extensiongroup=new FXGroupBox(iconsandext,"File Extensions",GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
   FXVerticalFrame *extensionFrame=new FXVerticalFrame(extensiongroup,LAYOUT_FILL_X|LAYOUT_FILL_Y|FRAME_SUNKEN|FRAME_THICK,0,0,0,0, 0,0,0,0);
-  extensions=new FXList(extensionFrame,3,NULL,0,LIST_BROWSESELECT|LAYOUT_FILL_X|LAYOUT_FILL_Y|HSCROLLER_NEVER);
+  extensions=new FXList(extensionFrame,NULL,0,LIST_BROWSESELECT|LAYOUT_FILL_X|LAYOUT_FILL_Y|HSCROLLER_NEVER);
   extensions->appendItem("fox.tar.gz");
   extensions->appendItem("tar.gz");
   extensions->appendItem("gz");
@@ -183,7 +183,7 @@ PropertyDialog::PropertyDialog(FXWindow *owner):
   new FXButton(mimebuttons,"Remove",NULL,this,ID_REMOVE_MIMETYPE,FRAME_RAISED|FRAME_THICK|LAYOUT_CENTER_Y|LAYOUT_CENTER_X);
 
   FXVerticalFrame *mimeFrame=new FXVerticalFrame(mimegroup,LAYOUT_SIDE_LEFT|LAYOUT_FILL_X|LAYOUT_FILL_Y|FRAME_SUNKEN|FRAME_THICK,0,0,0,0, 0,0,0,0);
-  mimetypes=new FXList(mimeFrame,3,this,ID_CHANGE_MIMETYPE,LIST_BROWSESELECT|LAYOUT_FILL_X|LAYOUT_FILL_Y|HSCROLLER_NEVER);
+  mimetypes=new FXList(mimeFrame,this,ID_CHANGE_MIMETYPE,LIST_BROWSESELECT|LAYOUT_FILL_X|LAYOUT_FILL_Y|HSCROLLER_NEVER);
 
   // Add a few if none exist yet
   mimetypes->appendItem("image/gif");
