@@ -19,7 +19,7 @@
 * along with this program; if not, write to the Free Software                   *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: ShutterBug.h,v 1.11 2003/09/10 03:54:37 fox Exp $                         *
+* $Id: ShutterBug.h,v 1.17 2004/04/28 16:29:07 fox Exp $                        *
 ********************************************************************************/
 #ifndef SHUTTERBUG_H
 #define SHUTTERBUG_H
@@ -30,20 +30,28 @@
 class Snapper;
 
 // Mini application object
-class ShutterBug : public FXMainWindow {
+class ShutterBug : public FXShell {
   FXDECLARE(ShutterBug)
 protected:
   FXString     filename;        // Filename last used
   FXint        fileformat;      // File format last chosen
+  FXColor     *clipbuffer;      // Clipped image buffer
+  FXint        clipwidth;       // Clipped image width
+  FXint        clipheight;      // Clipped image height
   Snapper     *snapper[4];      // Sides of area
   FXIcon      *bigicon;         // Big application icon
   FXIcon      *smallicon;       // Small application icon
+  FXIcon      *weighticons[6];  // Line weight icons
   FXRectangle  rectangle;       // Rectangle to snap
+  FXColor      color;           // Color of the snapshot lines
   FXint        weight;          // Weight of the snapshot lines
   FXint        size;            // Fixed size if not 0
+  FXuint       delay;           // Timer delay
+  FXbool       inside;          // Lines are inside
+  FXbool       quantize;        // Quantization mode
   FXint        spotx;           // Grab-spot of mouse on rectangle
   FXint        spoty;
-  FXuchar      mode;            // Draggind mode
+  FXuchar      mode;            // Dragging mode
 protected:
   ShutterBug(){}
   FXuchar where(FXint x,FXint y) const;
@@ -54,6 +62,7 @@ protected:
   void moveSnapRectangle(const FXRectangle& r);
   FXbool snapRectangle(FXColor*& data,const FXRectangle& r);
   void readPixels(FXImage* image,const FXRectangle& rectangle);
+  virtual FXbool doesOverrideRedirect() const;
 protected:
   enum {
     MODE_NONE        = 0,
@@ -70,6 +79,22 @@ protected:
 private:
   ShutterBug(const ShutterBug&);
   ShutterBug &operator=(const ShutterBug&);
+public:
+  static FXDragType bmpType;
+  static FXDragType gifType;
+  static FXDragType jpgType;
+  static FXDragType pngType;
+  static FXDragType tifType;
+  static FXDragType xpmType;
+  static FXDragType ppmType;
+public:
+  static const FXchar bmpTypeName[];
+  static const FXchar gifTypeName[];
+  static const FXchar jpgTypeName[];
+  static const FXchar pngTypeName[];
+  static const FXchar tifTypeName[];
+  static const FXchar xpmTypeName[];
+  static const FXchar ppmTypeName[];
 public:
   long onPaint(FXObject*,FXSelector,void*);
   long onMotion(FXObject*,FXSelector,void*);
@@ -83,20 +108,35 @@ public:
   long onEnterSnapper(FXObject*,FXSelector,void*);
   long onLeaveSnapper(FXObject*,FXSelector,void*);
   long onCmdSnap(FXObject*,FXSelector,void*);
+  long onCmdSnapDelayed(FXObject*,FXSelector,void*);
+  long onCmdSnapClipboard(FXObject*,FXSelector,void*);
+  long onCmdDelay(FXObject*,FXSelector,void*);
   long onCmdAbout(FXObject*,FXSelector,void*);
   long onCmdLasso(FXObject*,FXSelector,void*);
   long onUpdLasso(FXObject*,FXSelector,void*);
   long onCmdSize(FXObject*,FXSelector,void*);
   long onUpdSize(FXObject*,FXSelector,void*);
+  long onCmdQuit(FXObject*,FXSelector,void*);
+  long onCmdLineWeight(FXObject*,FXSelector,void*);
+  long onCmdLineColor(FXObject*,FXSelector,void*);
+  long onCmdLineInside(FXObject*,FXSelector,void*);
+  long onUpdLineInside(FXObject*,FXSelector,void*);
+  long onClipboardLost(FXObject*,FXSelector,void*);
+  long onClipboardRequest(FXObject*,FXSelector,void*);
+  long onCmdQuantize(FXObject*,FXSelector,void*);
+  long onUpdQuantize(FXObject*,FXSelector,void*);
 public:
   enum {
     ID_SNAPSHOT=FXMainWindow::ID_LAST,
+    ID_SNAPSHOT_DELAYED,
+    ID_SNAPSHOT_CLIPBOARD,
     ID_ABOUT,
     ID_TOGGLE_LASSO,
     ID_SNAPPER_0,
     ID_SNAPPER_1,
     ID_SNAPPER_2,
     ID_SNAPPER_3,
+    ID_SIZE_SCREEN,
     ID_SIZE_CUSTOM,
     ID_SIZE_8X8=ID_SIZE_CUSTOM+8,
     ID_SIZE_16X16=ID_SIZE_CUSTOM+16,
@@ -105,6 +145,18 @@ public:
     ID_SIZE_128X128=ID_SIZE_CUSTOM+128,
     ID_SIZE_256X256=ID_SIZE_CUSTOM+256,
     ID_SIZE_512X512=ID_SIZE_CUSTOM+512,
+    ID_WEIGHT_0,
+    ID_WEIGHT_1,
+    ID_WEIGHT_2,
+    ID_WEIGHT_3,
+    ID_WEIGHT_4,
+    ID_WEIGHT_5,
+    ID_WEIGHT_6,
+    ID_COLOR,
+    ID_DELAY,
+    ID_INSIDE,
+    ID_QUANTIZE,
+    ID_QUIT,
     ID_LAST
     };
 public:
@@ -115,9 +167,6 @@ public:
   /// Create
   virtual void create();
 
-  /// Close window
-  virtual FXbool close(FXbool notify);
-  
   /// Return the default width of this window
   virtual FXint getDefaultWidth();
 
