@@ -3,7 +3,7 @@
 *                             B i t m a p    O b j e c t                        *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXBitmap.cpp,v 1.48 2003/10/23 04:19:44 fox Exp $                        *
+* $Id: FXBitmap.cpp,v 1.67 2004/03/06 07:42:41 fox Exp $                        *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -56,12 +56,18 @@
       - The only drawback I can see is it will be a fairly large implementation
         effort...
 
-  - Need to implement restore, resize, and such.
-
+  - The scale, mirror, rotate and crop API's have been contributed by Marc Cartright,
+    <macartright@hotmail.com>.
+  - The XBM format maps 1 to black instead of white; perhaps this should
+    be reversed.
 */
 
 #define DISPLAY(app) ((Display*)((app)->display))
 
+// Changable bitmap options
+#define BITMAP_MASK   (BITMAP_KEEP|BITMAP_SHMI|BITMAP_SHMP)
+
+
 using namespace FX;
 
 /*******************************************************************************/
@@ -76,6 +82,7 @@ FXIMPLEMENT(FXBitmap,FXDrawable,NULL,0)
 // For deserialization
 FXBitmap::FXBitmap(){
   data=NULL;
+  bytewidth=0;
   options=0;
   }
 
@@ -83,11 +90,14 @@ FXBitmap::FXBitmap(){
 // Initialize
 FXBitmap::FXBitmap(FXApp* a,const void *pix,FXuint opts,FXint w,FXint h):FXDrawable(a,w,h){
   FXTRACE((100,"FXBitmap::FXBitmap %p\n",this));
+  FXASSERT((opts&~(BITMAP_OWNED|BITMAP_MASK))==0);
   visual=getApp()->getMonoVisual();
-  if(pix) opts&=~BITMAP_OWNED;
   data=(FXuchar*)pix;
+  bytewidth=(width+7)>>3;
   options=opts;
-  /// FIXME
+  if(!data && (options&BITMAP_OWNED)){
+    FXCALLOC(&data,FXuchar,height*bytewidth);
+    }
   }
 
 
@@ -237,7 +247,7 @@ struct BITMAPINFO2 {
 void FXBitmap::render(){
   if(xid){
     register FXuchar *p,*q,bits;
-    register FXint nb,i,j,bytes_per_line;
+    register FXint i,j,bytes_per_line;
     FXuchar *widedata;
 
     FXTRACE((100,"%s::render bitmap %p\n",getClassName(),this));
@@ -268,17 +278,16 @@ void FXBitmap::render(){
       bmi.bmiColors[1].rgbReserved=0;
 
       // Fill temp array
-      nb=(width+7)>>3;
       bytes_per_line=((width+31)&~31)>>3;
       FXCALLOC(&widedata,FXuchar,height*bytes_per_line);
       p=widedata+(height-1)*bytes_per_line;
       q=data;
       for(i=0; i<height; i++){
-        for(j=0; j<nb; j++){
+        for(j=0; j<bytewidth; j++){
           bits=~q[j];
           p[j]=FXBITREVERSE(bits);
           }
-        q+=nb;
+        q+=bytewidth;
         p-=bytes_per_line;
         }
 
@@ -297,25 +306,13 @@ void FXBitmap::render(){
 #endif
 
 
-// Get pixel at x,y
-FXbool FXBitmap::getPixel(FXint x,FXint y) const {
-  register FXint nb=(width+7)>>3;
-  return (data[y*nb+(x>>3)] & (1<<(x&7)))!=0;
-  }
-
-
-// Change pixel at x,y
-void FXBitmap::setPixel(FXint x,FXint y,FXbool color){
-  register FXint nb=(width+7)>>3;
-  if(color) data[y*nb+(x>>3)]|=(1<<(x&7)); else data[y*nb+(x>>3)]&=~(1<<(x&7));
-  }
-
-
 // Resize bitmap to the specified width and height; the contents become undefined
 void FXBitmap::resize(FXint w,FXint h){
+  register FXint bw;
   if(w<1) w=1;
   if(h<1) h=1;
-  FXTRACE((100,"%s::resize(%d,%d) %p\n",getClassName(),w,h,this));
+  FXTRACE((100,"%s::resize(%d,%d)\n",getClassName(),w,h));
+  bw=(w+7)>>3;
   if(xid){
 
 #ifndef WIN32
@@ -338,25 +335,268 @@ void FXBitmap::resize(FXint w,FXint h){
 
 #endif
     }
-  /// FIXME below
-/*
-  // Resize data array
+
+  // Resize data array; only do the work if the new
+  // array is a different size as measured in bytes!
   if(data){
-    if(!(options&IMAGE_OWNED)){       // Need to own array
-      FXMALLOC(&data,FXColor,w*h);
-      options|=IMAGE_OWNED;
+    if(!(options&BITMAP_OWNED)){        // Need to own array
+      FXMALLOC(&data,FXColor,h*bw);
+      options|=BITMAP_OWNED;
       }
-    else if(w*h!=width*height){
-      FXRESIZE(&data,FXColor,w*h);
+    else if(h*bw!=height*bytewidth){
+      FXRESIZE(&data,FXColor,h*bw);
       }
     }
-*/
+
   // Remember new size
+  bytewidth=bw;
   width=w;
   height=h;
   }
 
 
+// Fill bitmap with uniform value
+void FXBitmap::fill(FXbool color){
+  if(data){
+    memset(data,-color,height*bytewidth);
+    }
+  }
+
+
+// Rescale pixels to the specified width and height; just nearest
+// neighbor; there ain't no such thing as anti-aliasing in bitmaps!
+void FXBitmap::scale(FXint w,FXint h){
+  if(w<1) w=1;
+  if(h<1) h=1;
+  FXTRACE((100,"%s::scale(%d,%d)\n",getClassName(),w,h));
+  if(w!=width || h!=height){
+    if(data){
+      register FXuchar *q,*p,bits;
+      register FXint xs=(width<<16)/w;
+      register FXint ys=(height<<16)/h;
+      register FXint bw=bytewidth;
+      register FXint i,j,x,y,xx;
+      FXuchar *interim;
+
+      // Copy to old buffer
+      FXMEMDUP(&interim,data,FXuchar,height*bytewidth);
+
+      // Resize the pixmap and target buffer
+      resize(w,h);
+
+      // Scale the bitmap
+      i=0;
+      y=ys>>1;
+      p=data;
+      do{
+        j=0;
+        x=xs>>1;
+        q=interim+(y>>16)*bw;
+        bits=0;
+        do{
+          xx=x>>16;
+          bits|=((q[xx>>3]>>(xx&7))&1)<<(j&7);
+          if((j&7)==7){ *p++=bits; bits=0; }
+          x+=xs;
+          }
+        while(++j<w);
+        if(j&7){ *p++=bits; }
+        y+=ys;
+        }
+      while(++i<h);
+
+      // Free interim buffer
+      FXFREE(&interim);
+      render();
+      }
+    else{
+      resize(w,h);
+      }
+    }
+  }
+
+
+
+// Mirror bitmap horizontally and/or vertically
+void FXBitmap::mirror(FXbool horizontal,FXbool vertical){
+  FXTRACE((100,"%s::mirror(%d,%d)\n",getClassName(),horizontal,vertical));
+  if(horizontal || vertical){
+    if(data){
+      register FXuchar *paa,*pa,*pbb,*pb;
+      register FXint sa=(8-width)&7;
+      register FXint sb=8-sa;
+      register FXuint t;
+      FXuchar line[4096];               // Maximum width is 32768/8=4096 bytes
+      if(vertical && height>1){         // Mirror vertically
+        paa=data;
+        pbb=data+bytewidth*(height-1);
+        do{
+          pa=paa; paa+=bytewidth;
+          pb=pbb; pbb-=bytewidth;
+          do{
+            t=*pa; *pa++=*pb; *pb++=t;
+            }
+          while(pa<paa);
+          }
+        while(paa<pbb);
+        }
+      if(horizontal && width>1){        // Mirror horizontally
+        paa=data;
+        pbb=data+bytewidth*height;
+        do{
+          pa=paa;
+          pb=line+bytewidth;
+          do{
+            *--pb=*paa++;               // Gnarly!
+            }
+          while(line<pb);
+          do{
+            t=*pb++ << sa;
+            t|=*pb >> sb;
+            *pa++=FXBITREVERSE(t);
+            }
+          while(pa<paa);
+          }
+        while(paa<pbb);
+        }
+      render();
+      }
+    }
+  }
+
+
+// Rotate bitmap by degrees ccw
+void FXBitmap::rotate(FXint degrees){
+  FXTRACE((100,"%s::rotate(%d)\n",getClassName(),degrees));
+  degrees=(degrees+360)%360;
+  if(degrees!=0 && width>1 && height>1){
+    if(data){
+      register FXuchar *p,*q,bits;
+      register FXint bw=bytewidth;
+      register FXint i,j,x;
+      FXuchar *olddata;
+      FXMEMDUP(&olddata,data,FXuchar,bytewidth*height);
+      switch(degrees){
+        case 90:
+          resize(height,width);
+          i=height-1;
+          p=data;
+          do{
+            j=0;
+            q=olddata+(i>>3);
+            bits=0;
+            do{
+              bits|=((q[0]>>(i&7))&1)<<(j&7);
+              if((j&7)==7){ *p++=bits; bits=0; }
+              q+=bw;
+              }
+            while(++j<width);
+            if(j&7){ *p++=bits; }
+            }
+          while(--i>=0);
+          break;
+        case 180:               // FIXME works but not as fast as it could be
+          i=height-1;
+          p=data;
+          q=olddata+(height-1)*bw;
+          do{
+            j=0;
+            bits=0;
+            x=width-1;
+            do{
+              bits|=((q[x>>3]>>(x&7))&1)<<(j&7);
+              if((j&7)==7){ *p++=bits; bits=0; }
+              x--;
+              }
+            while(++j<width);
+            if(j&7){ *p++=bits; }
+            q-=bw;
+            }
+          while(--i>=0);
+          break;
+        case 270:
+          resize(height,width);
+          i=0;
+          p=data;
+          do{
+            j=0;
+            q=olddata+(i>>3)+(width-1)*bw;
+            bits=0;
+            do{
+              bits|=((q[0]>>(i&7))&1)<<(j&7);
+              if((j&7)==7){ *p++=bits; bits=0; }
+              q-=bw;
+              }
+            while(++j<width);
+            if(j&7){ *p++=bits; }
+            }
+          while(++i<height);
+          break;
+        default:
+          fxwarning("%s::rotate: rotation by %d degrees not implemented.\n",getClassName(),degrees);
+          break;
+        }
+      FXFREE(&olddata);
+      render();
+      }
+    else{
+      switch(degrees){
+        case 90:
+          resize(height,width);
+          break;
+        case 180:
+          resize(width,height);
+          break;
+        case 270:
+          resize(height,width);
+          break;
+        default:
+          fxwarning("%s::rotate: rotation by %d degrees not implemented.\n",getClassName(),degrees);
+          break;
+        }
+      }
+    }
+  }
+
+
+// Crop bitmap to given rectangle
+void FXBitmap::crop(FXint x,FXint y,FXint w,FXint h){
+  if(w<1) w=1;
+  if(h<1) h=1;
+  if(x<0 || y<0 || w>width || y+h>height) { fxerror("%s::crop: rectangle outside of bitmap.\n",getClassName()); }
+  FXTRACE((1,"%s::crop(%d,%d,%d,%d)\n",getClassName(),x,y,w,h));
+  if(data){
+    register FXuchar *paa,*pbb,*end,*pa,*pb;
+    register FXint oldbw=bytewidth;
+    register FXint newbw=(w+7)>>3;
+    register FXint size=height*bytewidth;
+    register FXint sh=x&7;
+    register FXuint t;
+    FXuchar *olddata;
+    FXMALLOC(&olddata,FXuchar,size+1);          // Yes, one extra byte!
+    memcpy(olddata,data,size);
+    pbb=olddata+bytewidth*y+(x>>3);
+    resize(w,h);
+    paa=data;
+    end=data+h*bytewidth;
+    do{
+      pa=paa; paa+=newbw;
+      pb=pbb; pbb+=oldbw;
+      do{
+        t=*pb++; t|=*pb<<8; *pa++=t>>sh;        // Because of here!
+        }
+      while(pa<paa);
+      }
+    while(paa<end);
+    FXFREE(&olddata);
+    render();
+    }
+  else{
+    resize(w,h);
+    }
+  }
+
+
 #ifdef WIN32
 
 // Get the image's device context
@@ -375,9 +615,15 @@ int FXBitmap::ReleaseDC(FXID hdc) const {
 #endif
 
 
+// Change options
+void FXBitmap::setOptions(FXuint opts){
+  options=(options&~BITMAP_MASK) | (opts&BITMAP_MASK);
+  }
+
+
 // Save pixel data only
 FXbool FXBitmap::savePixels(FXStream& store) const {
-  FXuint size=height*((width+7)>>3);
+  FXuint size=height*bytewidth;
   store.save(data,size);
   return TRUE;
   }
@@ -385,7 +631,7 @@ FXbool FXBitmap::savePixels(FXStream& store) const {
 
 // Load pixel data only
 FXbool FXBitmap::loadPixels(FXStream& store){
-  FXuint size=height*((width+7)>>3);
+  FXuint size=height*bytewidth;
   if(options&BITMAP_OWNED){ FXFREE(&data); }
   if(!FXMALLOC(&data,FXuchar,size)) return FALSE;
   store.load(data,size);
