@@ -3,7 +3,7 @@
 *                                D i a l   W i d g e t                          *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXDial.cpp,v 1.32 2003/10/23 17:53:17 fox Exp $                          *
+* $Id: FXDial.cpp,v 1.34 2004/03/25 15:18:17 fox Exp $                          *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -329,38 +329,33 @@ long FXDial::onMotion(FXObject*,FXSelector,void* ptr){
 long FXDial::onMouseWheel(FXObject*,FXSelector,void* ptr){
   FXEvent *event=(FXEvent*)ptr;
   FXint delta,newpos,tmp,mod;
+  
+  // Determine the change in dial units; this probably still needs
+  // tweaking. The formula below adjusts the dial position by 1/36
+  // of a revolution for each "hop" of the mousewheel.
+  delta=(event->code*incr)/4320;
 
-  // Any motion?
-  if(event->code){
-
-    // Determine the change in dial units; this probably still needs
-    // tweaking. The formula below adjusts the dial position by 1/36
-    // of a revolution for each "hop" of the mousewheel.
-    delta=(event->code*incr)/4320;
-
-    // Determine new dial position
-    if(options&DIAL_CYCLIC){
-      mod=range[1]-range[0]+1;
-      tmp=pos+delta-range[0];
-      while(tmp<0) tmp+=mod;
-      newpos=range[0]+tmp%mod;        // FIXME small problem if range[1]-range[0]+1 is UINT_MAX
-      }
-    else{
-      if(pos+delta<range[0]) newpos=range[0];
-      else if(pos+delta>range[1]) newpos=range[1];
-      else newpos=pos+delta;
-      }
-    if(pos!=newpos){
-      pos=newpos;
-      FXASSERT(range[0]<=pos && pos<=range[1]);
-      notchangle=(notchoffset+(3600*(pos-range[0]))/incr)%3600;
-      update(border+padleft+1,border+padtop+1,width-(border<<1)-padleft-padright-2,height-(border<<1)-padtop-padbottom-2);
-      if(target) target->handle(this,FXSEL(SEL_CHANGED,message),(void*)(FXival)pos);
-      if(target) target->handle(this,FXSEL(SEL_COMMAND,message),(void*)(FXival)pos);
-      return 1;
-      }
+  // Determine new dial position
+  if(options&DIAL_CYCLIC){
+    mod=range[1]-range[0]+1;
+    tmp=pos+delta-range[0];
+    while(tmp<0) tmp+=mod;
+    newpos=range[0]+tmp%mod;        // FIXME small problem if range[1]-range[0]+1 is UINT_MAX
     }
-  return 0;
+  else{
+    if(pos+delta<range[0]) newpos=range[0];
+    else if(pos+delta>range[1]) newpos=range[1];
+    else newpos=pos+delta;
+    }
+  if(pos!=newpos){
+    pos=newpos;
+    FXASSERT(range[0]<=pos && pos<=range[1]);
+    notchangle=(notchoffset+(3600*(pos-range[0]))/incr)%3600;
+    update(border+padleft+1,border+padtop+1,width-(border<<1)-padleft-padright-2,height-(border<<1)-padtop-padbottom-2);
+    if(target) target->handle(this,FXSEL(SEL_CHANGED,message),(void*)(FXival)pos);
+    if(target) target->handle(this,FXSEL(SEL_COMMAND,message),(void*)(FXival)pos);
+    }
+  return 1;
   }
 
 
