@@ -3,7 +3,7 @@
 *                      O p e n G L   C y l i n d e r   O b j e c t              *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1999,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1999,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * Contributed by: Angel-Ventura Mendo Gomez <ventura@labri.u-bordeaux.fr>       *
 *********************************************************************************
@@ -21,7 +21,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXGLCylinder.cpp,v 1.19 2003/10/23 04:19:44 fox Exp $                    *
+* $Id: FXGLCylinder.cpp,v 1.21 2004/02/20 16:29:39 fox Exp $                    *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -32,7 +32,7 @@
 #include "FXVec4f.h"
 #include "FXQuatf.h"
 #include "FXMat4f.h"
-#include "FXRange.h"
+#include "FXRangef.h"
 #include "FXString.h"
 #include "FXSize.h"
 #include "FXPoint.h"
@@ -70,9 +70,9 @@ FXIMPLEMENT(FXGLCylinder,FXGLShape,NULL,0)
 // Create cylinder
 FXGLCylinder::FXGLCylinder():height(1.0f),radius(1.0f){
   FXTRACE((100,"FXGLCylinder::FXGLCylinder\n"));
-  range[0][0]=-radius; range[0][1]=radius;
-  range[1][0]=0.0f;    range[1][1]=height;
-  range[2][0]=-radius; range[2][1]=radius;
+  range.lower.x=-radius; range.upper.x=radius;
+  range.lower.y=0.0f;    range.upper.y=height;
+  range.lower.z=-radius; range.upper.z=radius;
   }
 
 
@@ -80,9 +80,9 @@ FXGLCylinder::FXGLCylinder():height(1.0f),radius(1.0f){
 FXGLCylinder::FXGLCylinder(FXfloat x,FXfloat y,FXfloat z,FXfloat h,FXfloat r):
   FXGLShape(x,y,z,SHADING_SMOOTH|STYLE_SURFACE),height(h),radius(r){
   FXTRACE((100,"FXGLCylinder::FXGLCylinder\n"));
-  range[0][0]=-radius; range[0][1]=radius;
-  range[1][0]=0.0f;    range[1][1]=height;
-  range[2][0]=-radius; range[2][1]=radius;
+  range.lower.x=-radius; range.upper.x=radius;
+  range.lower.y=0.0f;    range.upper.y=height;
+  range.lower.z=-radius; range.upper.z=radius;
   }
 
 
@@ -90,9 +90,9 @@ FXGLCylinder::FXGLCylinder(FXfloat x,FXfloat y,FXfloat z,FXfloat h,FXfloat r):
 FXGLCylinder::FXGLCylinder(FXfloat x,FXfloat y,FXfloat z,FXfloat h,FXfloat r,const FXMaterial& mtl):
   FXGLShape(x,y,z,SHADING_SMOOTH|STYLE_SURFACE,mtl,mtl),height(h),radius(r){
   FXTRACE((100,"FXGLCylinder::FXGLCylinder\n"));
-  range[0][0]=-radius; range[0][1]=radius;
-  range[1][0]=0.0f;    range[1][1]=height;
-  range[2][0]=-radius; range[2][1]=radius;
+  range.lower.x=-radius; range.upper.x=radius;
+  range.lower.y=0.0f;    range.upper.y=height;
+  range.lower.z=-radius; range.upper.z=radius;
   }
 
 
