@@ -3,7 +3,7 @@
 *                      O p e n G L   S h a p e   O b j e c t                    *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1999,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1999,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * Contributed by: Angel-Ventura Mendo Gomez <ventura@labri.u-bordeaux.fr>       *
 *********************************************************************************
@@ -21,7 +21,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXGLShape.cpp,v 1.33 2003/10/23 04:19:44 fox Exp $                       *
+* $Id: FXGLShape.cpp,v 1.35 2004/02/20 16:29:39 fox Exp $                       *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -32,7 +32,7 @@
 #include "FXVec4f.h"
 #include "FXQuatf.h"
 #include "FXMat4f.h"
-#include "FXRange.h"
+#include "FXRangef.h"
 #include "FXString.h"
 #include "FXSize.h"
 #include "FXPoint.h"
@@ -85,17 +85,22 @@ FXGLShape::FXGLShape(){
   position.x=0.0f;
   position.y=0.0f;
   position.z=0.0f;
-  material[0].ambient=FXVec4f(0.2f,0.2f,0.2f,1.0f);      // Front facing material
+  material[0].ambient=FXVec4f(0.2f,0.2f,0.2f,1.0f);
   material[0].diffuse=FXVec4f(0.8f,0.8f,0.8f,1.0f);
   material[0].specular=FXVec4f(1.0f,1.0f,1.0f,1.0f);
   material[0].emission=FXVec4f(0.0f,0.0f,0.0f,1.0f);
   material[0].shininess=30.0f;
-  material[1].ambient=FXVec4f(0.2f,0.2f,0.2f,1.0f);      // Back facing material
+  material[1].ambient=FXVec4f(0.2f,0.2f,0.2f,1.0f);
   material[1].diffuse=FXVec4f(0.8f,0.8f,0.8f,1.0f);
   material[1].specular=FXVec4f(1.0f,1.0f,1.0f,1.0f);
   material[1].emission=FXVec4f(0.0f,0.0f,0.0f,1.0f);
   material[1].shininess=30.0;
-  range=FXRange(-1.0f,1.0f,-1.0f,1.0f,-1.0f,1.0f);       // Ample bounding box
+  range.lower.x=-1.0f;
+  range.lower.y=-1.0f;
+  range.lower.z=-1.0f;
+  range.upper.x= 1.0f;
+  range.upper.y= 1.0f;
+  range.upper.z= 1.0f;
   options=SHADING_SMOOTH|STYLE_SURFACE;
   }
 
@@ -115,7 +120,12 @@ FXGLShape::FXGLShape(FXfloat x,FXfloat y,FXfloat z,FXuint opts){
   material[1].specular=FXVec4f(1.0f,1.0f,1.0f,1.0f);
   material[1].emission=FXVec4f(0.0f,0.0f,0.0f,1.0f);
   material[1].shininess=30.0f;
-  range=FXRange(-1.0f,1.0f,-1.0f,1.0f,-1.0f,1.0f);
+  range.lower.x=-1.0f;
+  range.lower.y=-1.0f;
+  range.lower.z=-1.0f;
+  range.upper.x= 1.0f;
+  range.upper.y= 1.0f;
+  range.upper.z= 1.0f;
   options=opts;
   }
 
@@ -127,7 +137,12 @@ FXGLShape::FXGLShape(FXfloat x,FXfloat y,FXfloat z,FXuint opts,const FXMaterial&
   position.z=z;
   material[0]=front;
   material[1]=back;
-  range=FXRange(-1.0f,1.0f,-1.0f,1.0f,-1.0f,1.0f);
+  range.lower.x=-1.0f;           
+  range.lower.y=-1.0f;
+  range.lower.z=-1.0f;
+  range.upper.x= 1.0f;
+  range.upper.y= 1.0f;
+  range.upper.z= 1.0f;
   options=opts;
   }
 
@@ -393,10 +408,10 @@ void FXGLShape::hit(FXGLViewer* viewer){
 
 
 // Get bounding box
-void FXGLShape::bounds(FXRange& box){
-  box[0][0]=position[0]+range[0][0]; box[0][1]=position[0]+range[0][1];
-  box[1][0]=position[1]+range[1][0]; box[1][1]=position[1]+range[1][1];
-  box[2][0]=position[2]+range[2][0]; box[2][1]=position[2]+range[2][1];
+void FXGLShape::bounds(FXRangef& box){
+  box.lower.x=position.x+range.lower.x; box.upper.x=position.x+range.upper.x;
+  box.lower.y=position.y+range.lower.y; box.upper.y=position.y+range.upper.y;
+  box.lower.z=position.z+range.lower.z; box.upper.z=position.z+range.upper.z;
   }
 
 
@@ -404,24 +419,24 @@ void FXGLShape::bounds(FXRange& box){
 void FXGLShape::drawbox(){
 #ifdef HAVE_GL_H
   glBegin(GL_LINE_LOOP);
-  glVertex3f(range[0][1], range[1][0], range[2][0]);
-  glVertex3f(range[0][1], range[1][0], range[2][1]);
-  glVertex3f(range[0][0], range[1][0], range[2][1]);
-  glVertex3f(range[0][0], range[1][1], range[2][1]);
-  glVertex3f(range[0][1], range[1][1], range[2][1]);
-  glVertex3f(range[0][1], range[1][1], range[2][0]);
-  glVertex3f(range[0][0], range[1][1], range[2][0]);
-  glVertex3f(range[0][0], range[1][0], range[2][0]);
+  glVertex3f(range.upper.x, range.lower.y, range.lower.z);
+  glVertex3f(range.upper.x, range.lower.y, range.upper.z);
+  glVertex3f(range.lower.x, range.lower.y, range.upper.z);
+  glVertex3f(range.lower.x, range.upper.y, range.upper.z);
+  glVertex3f(range.upper.x, range.upper.y, range.upper.z);
+  glVertex3f(range.upper.x, range.upper.y, range.lower.z);
+  glVertex3f(range.lower.x, range.upper.y, range.lower.z);
+  glVertex3f(range.lower.x, range.lower.y, range.lower.z);
   glEnd();
   glBegin(GL_LINES);
-  glVertex3f(range[0][0], range[1][0], range[2][0]);
-  glVertex3f(range[0][0], range[1][0], range[2][1]);
-  glVertex3f(range[0][0], range[1][1], range[2][0]);
-  glVertex3f(range[0][0], range[1][1], range[2][1]);
-  glVertex3f(range[0][1], range[1][0], range[2][0]);
-  glVertex3f(range[0][1], range[1][1], range[2][0]);
-  glVertex3f(range[0][1], range[1][0], range[2][1]);
-  glVertex3f(range[0][1], range[1][1], range[2][1]);
+  glVertex3f(range.lower.x, range.lower.y, range.lower.z);
+  glVertex3f(range.lower.x, range.lower.y, range.upper.z);
+  glVertex3f(range.lower.x, range.upper.y, range.lower.z);
+  glVertex3f(range.lower.x, range.upper.y, range.upper.z);
+  glVertex3f(range.upper.x, range.lower.y, range.lower.z);
+  glVertex3f(range.upper.x, range.upper.y, range.lower.z);
+  glVertex3f(range.upper.x, range.lower.y, range.upper.z);
+  glVertex3f(range.upper.x, range.upper.y, range.upper.z);
   glEnd();
 #endif
   }
@@ -431,14 +446,14 @@ void FXGLShape::drawbox(){
 void FXGLShape::drawhandles(){
 #ifdef HAVE_GL_H
   glBegin(GL_POINTS);
-  glVertex3f(range[0][0], range[1][0], range[2][0]);
-  glVertex3f(range[0][0], range[1][0], range[2][1]);
-  glVertex3f(range[0][0], range[1][1], range[2][0]);
-  glVertex3f(range[0][0], range[1][1], range[2][1]);
-  glVertex3f(range[0][1], range[1][0], range[2][0]);
-  glVertex3f(range[0][1], range[1][0], range[2][1]);
-  glVertex3f(range[0][1], range[1][1], range[2][0]);
-  glVertex3f(range[0][1], range[1][1], range[2][1]);
+  glVertex3f(range.lower.x, range.lower.y, range.lower.z);
+  glVertex3f(range.lower.x, range.lower.y, range.upper.z);
+  glVertex3f(range.lower.x, range.upper.y, range.lower.z);
+  glVertex3f(range.lower.x, range.upper.y, range.upper.z);
+  glVertex3f(range.upper.x, range.lower.y, range.lower.z);
+  glVertex3f(range.upper.x, range.lower.y, range.upper.z);
+  glVertex3f(range.upper.x, range.upper.y, range.lower.z);
+  glVertex3f(range.upper.x, range.upper.y, range.upper.z);
   glEnd();
 #endif
   }
