@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXIcon.cpp,v 1.62.2.1 2004/08/28 01:10:02 fox Exp $                          *
+* $Id: FXIcon.cpp,v 1.62 2004/04/28 16:29:07 fox Exp $                          *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -382,11 +382,10 @@ struct BITMAPINFO2 {
 // Render Icon MS-Windows
 void FXIcon::render(){
   if(xid){
-    register FXint bytes_per_line,x,y;
-    register FXuchar *msk,*ets;
+    register FXuchar *maskdata,*etchdata,*msk,*ets;
     register FXColor *img;
-    FXuchar *maskdata;
-    FXuchar *etchdata;
+    register FXint x,y;
+    register FXuint bytes_per_line;
     BITMAPINFO2 bmi;
     HDC hdcmsk;
 
