@@ -3,7 +3,7 @@
 *                            L i s t   O b j e c t                              *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXList.cpp,v 1.128 2003/10/23 04:19:45 fox Exp $                         *
+* $Id: FXList.cpp,v 1.131 2004/02/08 17:29:06 fox Exp $                         *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -322,7 +322,7 @@ FXList::FXList(){
 
 
 // List
-FXList::FXList(FXComposite *p,FXint nvis,FXObject* tgt,FXSelector sel,FXuint opts,FXint x,FXint y,FXint w,FXint h):
+FXList::FXList(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint opts,FXint x,FXint y,FXint w,FXint h):
   FXScrollArea(p,opts,x,y,w,h){
   flags|=FLAG_ENABLED;
   target=tgt;
@@ -339,7 +339,7 @@ FXList::FXList(FXComposite *p,FXint nvis,FXObject* tgt,FXSelector sel,FXuint opt
   seltextColor=getApp()->getSelforeColor();
   listWidth=0;
   listHeight=0;
-  visible=FXMAX(nvis,0);
+  visible=0;
   sortfunc=NULL;
   grabx=0;
   graby=0;
@@ -451,9 +451,6 @@ FXint FXList::getContentHeight(){
 // Recalculate layout determines item locations and sizes
 void FXList::layout(){
 
-  // Force repaint if content changed
-  //if(flags&FLAG_RECALC) update();
-
   // Calculate contents
   FXScrollArea::layout();
 
@@ -548,9 +545,8 @@ FXbool FXList::isItemVisible(FXint index) const {
 
 // Make item fully visible
 void FXList::makeItemVisible(FXint index){
-  FXint y,h;
-  if(xid==0) return;
-  if(0<=index && index<nitems){
+  register FXint y,h;
+  if(xid && 0<=index && index<nitems){
     y=pos_y;
     h=items[index]->getHeight(this);
     if(viewport_h<=y+items[index]->y+h) y=viewport_h-items[index]->y-h;
