@@ -3,7 +3,7 @@
 *                             O p t i o n   M e n u                             *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXOptionMenu.cpp,v 1.48 2003/10/23 04:19:45 fox Exp $                    *
+* $Id: FXOptionMenu.cpp,v 1.50 2004/02/08 17:29:07 fox Exp $                    *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -415,31 +415,37 @@ long FXOptionMenu::onPaint(FXObject*,FXSelector,void* ptr){
     ih=icon->getHeight();
     }
 
-  // Keep some room for the arrow!
   just_x(tx,ix,tw,iw);
   just_y(ty,iy,th,ih);
 
-  // Draw icon
-  if(icon){
-    dc.drawIcon(icon,ix,iy);
-    }
-
-  // Or draw rectangle
-  else{
-    drawDoubleRaisedRectangle(dc,ix,iy,MENUGLYPH_WIDTH,MENUGLYPH_HEIGHT);
-    }
-
-  // Draw text
-  if(!label.empty()){
-    dc.setFont(font);
-    if(isEnabled()){
-      dc.setForeground(textColor);
-      drawLabel(dc,label,hotoff,tx,ty,tw,th);
-      if(hasFocus()){
-        dc.drawFocusRectangle(border+1,border+1,width-2*border-2,height-2*border-2);
-        }
+  // Draw enabled state
+  if(isEnabled()){
+    if(icon){
+      dc.drawIcon(icon,ix,iy);
       }
     else{
+      drawDoubleRaisedRectangle(dc,ix,iy,MENUGLYPH_WIDTH,MENUGLYPH_HEIGHT);
+      }
+    if(!label.empty()){
+      dc.setFont(font);
+      dc.setForeground(textColor);
+      drawLabel(dc,label,hotoff,tx,ty,tw,th);
+      }
+    if(hasFocus()){
+      dc.drawFocusRectangle(border+1,border+1,width-2*border-2,height-2*border-2);
+      }
+    }
+
+  // Draw grayed-out state
+  else{
+    if(icon){
+      dc.drawIconSunken(icon,ix,iy);
+      }
+    else{
+      drawDoubleRaisedRectangle(dc,ix,iy,MENUGLYPH_WIDTH,MENUGLYPH_HEIGHT);
+      }
+    if(!label.empty()){
+      dc.setFont(font);
       dc.setForeground(hiliteColor);
       drawLabel(dc,label,hotoff,tx+1,ty+1,tw,th);
       dc.setForeground(shadowColor);
