@@ -3,7 +3,7 @@
 *             R e a l - V a l u e d   S p i n n e r  W i d g e t                *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2003 by Bill Baxter.   All Rights Reserved.                     *
+* Copyright (C) 2003,2004 by Bill Baxter.   All Rights Reserved.                *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXRealSpinner.cpp,v 1.16 2003/10/23 04:19:45 fox Exp $                   *
+* $Id: FXRealSpinner.cpp,v 1.20 2004/02/19 15:37:45 fox Exp $                   *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -66,6 +66,7 @@ namespace FX {
 FXDEFMAP(FXRealSpinner) FXRealSpinnerMap[]={
   FXMAPFUNC(SEL_KEYPRESS,0,FXRealSpinner::onKeyPress),
   FXMAPFUNC(SEL_KEYRELEASE,0,FXRealSpinner::onKeyRelease),
+  FXMAPFUNC(SEL_FOCUS_SELF,0,FXRealSpinner::onFocusSelf),
   FXMAPFUNC(SEL_UPDATE,FXRealSpinner::ID_ENTRY,FXRealSpinner::onUpdEntry),
   FXMAPFUNC(SEL_COMMAND,FXRealSpinner::ID_ENTRY,FXRealSpinner::onCmdEntry),
   FXMAPFUNC(SEL_CHANGED,FXRealSpinner::ID_ENTRY,FXRealSpinner::onChgEntry),
@@ -198,10 +199,12 @@ long FXRealSpinner::onUpdIncrement(FXObject* sender,FXSelector,void*){
 
 // Respond to increment message
 long FXRealSpinner::onCmdIncrement(FXObject*,FXSelector,void*){
-  if(!isEnabled()) return 0;
-  increment();
-  if(target) target->handle(this,FXSEL(SEL_COMMAND,message),(void*)(FXival)pos);
-  return 1;
+  if(isEnabled() && isEditable()){
+    increment();
+    if(target) target->handle(this,FXSEL(SEL_COMMAND,message),(void*)&pos);
+    return 1;
+    }
+  return 0;
   }
 
 
@@ -217,18 +220,26 @@ long FXRealSpinner::onUpdDecrement(FXObject* sender,FXSelector,void*){
 
 // Respond to decrement message
 long FXRealSpinner::onCmdDecrement(FXObject*,FXSelector,void*){
-  if(!isEnabled()) return 0;
-  decrement();
-  if(target) target->handle(this,FXSEL(SEL_COMMAND,message),(void*)(FXival)pos);
-  return 1;
+  if(isEnabled() && isEditable()){
+    decrement();
+    if(target) target->handle(this,FXSEL(SEL_COMMAND,message),(void*)&pos);
+    return 1;
+    }
+  return 0;
   }
 
 
 // Rolling mouse wheel in text field behaves as if inside dial
 long FXRealSpinner::onWheelEntry(FXObject*,FXSelector,void* ptr){
-  if(((FXEvent*)ptr)->code>0) increment(); else decrement();
-  if(target) target->handle(this,FXSEL(SEL_COMMAND,message),(void*)(FXival)pos);
-  return 1;
+  if(isEnabled() && isEditable()){
+    if(((FXEvent*)ptr)->code>0) 
+      increment(); 
+    else 
+      decrement();
+    if(target) target->handle(this,FXSEL(SEL_COMMAND,message),(void*)&pos);
+    return 1;
+    }
+  return 0;
   }
 
 
@@ -262,21 +273,32 @@ long FXRealSpinner::onCmdEntry(FXObject*,FXSelector,void*){
 // Keyboard press
 long FXRealSpinner::onKeyPress(FXObject* sender,FXSelector sel,void* ptr){
   FXEvent* event=(FXEvent*)ptr;
-  if(!isEnabled()) return 0;
-  if(target && target->handle(this,FXSEL(SEL_KEYPRESS,message),ptr)) return 1;
-  switch(event->code){
-    case KEY_Up:
-    case KEY_KP_Up:
-      increment();
-      if(target) target->handle(this,FXSEL(SEL_COMMAND,message),(void*)&pos);
-      return 1;
-    case KEY_Down:
-    case KEY_KP_Down:
-      decrement();
-      if(target) target->handle(this,FXSEL(SEL_COMMAND,message),(void*)&pos);
-      return 1;
-    default:
-      return textField->handle(sender,sel,ptr);
+  if(isEnabled()){
+    if(target && target->handle(this,FXSEL(SEL_KEYPRESS,message),ptr)) return 1;
+    switch(event->code){
+      case KEY_Up:
+      case KEY_KP_Up:
+        if(isEditable()){
+          increment();
+          if(target) target->handle(this,FXSEL(SEL_COMMAND,message),(void*)&pos);
+          }
+        else{
+          getApp()->beep();
+          }
+        return 1;
+      case KEY_Down:
+      case KEY_KP_Down:
+        if(isEditable()){
+          decrement();
+          if(target) target->handle(this,FXSEL(SEL_COMMAND,message),(void*)&pos);
+          }
+        else{
+          getApp()->beep();
+          }
+        return 1;
+      default:
+        return textField->handle(sender,sel,ptr);
+      }
     }
   return 0;
   }
@@ -285,21 +307,28 @@ long FXRealSpinner::onKeyPress(FXObject* sender,FXSelector sel,void* ptr){
 // Keyboard release
 long FXRealSpinner::onKeyRelease(FXObject* sender,FXSelector sel,void* ptr){
   FXEvent* event=(FXEvent*)ptr;
-  if(!isEnabled()) return 0;
-  if(target && target->handle(this,FXSEL(SEL_KEYRELEASE,message),ptr)) return 1;
-  switch(event->code){
-    case KEY_Up:
-    case KEY_KP_Up:
-    case KEY_Down:
-    case KEY_KP_Down:
-      return 1;
-    default:
-      return textField->handle(sender,sel,ptr);
+  if(isEnabled()){
+    if(target && target->handle(this,FXSEL(SEL_KEYRELEASE,message),ptr)) return 1;
+    switch(event->code){
+      case KEY_Up:
+      case KEY_KP_Up:
+      case KEY_Down:
+      case KEY_KP_Down:
+        return 1;
+      default:
+        return textField->handle(sender,sel,ptr);
+      }
     }
   return 0;
   }
 
 
+// Force focus on the text field
+long FXRealSpinner::onFocusSelf(FXObject* sender,FXSelector,void* ptr){
+  return textField->handle(sender,FXSEL(SEL_FOCUS_SELF,0),ptr);
+  }
+
+
 // Update value from a message
 long FXRealSpinner::onCmdSetValue(FXObject*,FXSelector,void* ptr){
   setValue((FXdouble)(FXival)ptr);
