@@ -1,9 +1,9 @@
 /********************************************************************************
 *                                                                               *
-*                             S l i d e r   O b j e c t s                       *
+*                           S l i d e r   W i d g e t                           *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXSlider.cpp,v 1.46 2003/10/23 17:53:17 fox Exp $                        *
+* $Id: FXSlider.cpp,v 1.52 2004/03/25 23:11:04 fox Exp $                        *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -40,18 +40,7 @@
 
 /*
   Notes:
-  - Add API's to change sizes and appearance.
-  - Dual/triple head options.
-  - Need to be able to disable/enable, head should show/hide.
-  - Sliderhead starts too small for SLIDER_INSIDE_BAR mode.
-  - What messages should be sent?
-  - Slider should work in double, not int.
-  - setValue should not move head unless current headpos does not
-    reflect pos (due to resolution issues, several headpos's might
-    map to the same pos).
-  - If changing pos, you may or may not have to move the head;
-    if changing the head, you may or may not get a new pos.
-  - In case of a coarse range, we have rounding also.
+  - Maybe add bindings for arrow keys for value changes.
 */
 
 #define TICKSIZE        4           // Length of ticks
@@ -72,6 +61,7 @@ namespace FX {
 FXDEFMAP(FXSlider) FXSliderMap[]={
   FXMAPFUNC(SEL_PAINT,0,FXSlider::onPaint),
   FXMAPFUNC(SEL_MOTION,0,FXSlider::onMotion),
+  FXMAPFUNC(SEL_MOUSEWHEEL,0,FXSlider::onMouseWheel),
   FXMAPFUNC(SEL_LEFTBUTTONPRESS,0,FXSlider::onLeftBtnPress),
   FXMAPFUNC(SEL_LEFTBUTTONRELEASE,0,FXSlider::onLeftBtnRelease),
   FXMAPFUNC(SEL_MIDDLEBUTTONPRESS,0,FXSlider::onMiddleBtnPress),
@@ -102,7 +92,7 @@ FXIMPLEMENT(FXSlider,FXFrame,FXSliderMap,ARRAYNUMBER(FXSliderMap))
 
 // Make a slider
 FXSlider::FXSlider(){
-  flags|=FLAG_ENABLED|FLAG_SHOWN;
+  flags|=FLAG_ENABLED;
   headpos=0;
   dragpoint=0;
   }
@@ -111,7 +101,12 @@ FXSlider::FXSlider(){
 // Make a slider
 FXSlider::FXSlider(FXComposite* p,FXObject* tgt,FXSelector sel,FXuint opts,FXint x,FXint y,FXint w,FXint h,FXint pl,FXint pr,FXint pt,FXint pb):
   FXFrame(p,opts,x,y,w,h,pl,pr,pt,pb){
-  flags|=FLAG_ENABLED|FLAG_SHOWN;
+  flags|=FLAG_ENABLED;
+  slotColor=getApp()->getBackColor();
+  baseColor=getApp()->getBaseColor();
+  hiliteColor=getApp()->getHiliteColor();
+  shadowColor=getApp()->getShadowColor();
+  borderColor=getApp()->getBorderColor();
   target=tgt;
   message=sel;
   range[0]=0;
@@ -119,11 +114,6 @@ FXSlider::FXSlider(FXComposite* p,FXObject* tgt,FXSelector sel,FXuint opts,FXint
   pos=50;
   incr=1;
   delta=0;
-  slotColor=getApp()->getBackColor();
-  baseColor=getApp()->getBaseColor();
-  hiliteColor=getApp()->getHiliteColor();
-  shadowColor=getApp()->getShadowColor();
-  borderColor=getApp()->getBorderColor();
   headpos=0;
   dragpoint=0;
   headsize=(options&SLIDER_INSIDE_BAR)?HEADINSIDEBAR:HEADOVERHANGING;
@@ -149,46 +139,6 @@ void FXSlider::disable(){
   }
 
 
-// Return head position from value
-FXint FXSlider::headPos(FXint v) const {
-  register FXint travel,rr,p;
-  if(v<range[0]) v=range[0];
-  if(v>range[1]) v=range[1];
-  rr=range[1]-range[0];
-  if(options&SLIDER_VERTICAL){
-    p=border+padtop+2;
-    travel=height-(border<<1)-padtop-padbottom-headsize-4;
-    if(rr>0) p+=(travel*(range[1]-v))/rr;
-    }
-  else{
-    p=border+padleft+2;
-    travel=width-(border<<1)-padleft-padright-headsize-4;
-    if(rr>0) p+=(travel*(v-range[0]))/rr;
-    }
-  return p;
-  }
-
-
-// Return value from head position
-FXint FXSlider::headVal(FXint p) const {
-  register FXint travel,rr,v;
-  rr=range[1]-range[0];
-  if(options&SLIDER_VERTICAL){
-    v=range[0];
-    travel=height-(border<<1)-padtop-padbottom-headsize-4;
-    if(travel>0) v+=(rr*(border+padtop+2+travel-p)+travel/2)/travel;
-    }
-  else{
-    v=range[0];
-    travel=width-(border<<1)-padleft-padright-headsize-4;
-    if(travel>0) v+=(rr*(p-border-padleft-2)+travel/2)/travel;
-    }
-  if(v<range[0]) v=range[0];
-  if(v>range[1]) v=range[1];
-  return v;
-  }
-
-
 // Get default size
 FXint FXSlider::getDefaultWidth(){
   FXint w;
@@ -322,14 +272,15 @@ long FXSlider::onCmdSetIntRange(FXObject*,FXSelector,void* ptr){
 
 // Get range with a message
 long FXSlider::onCmdGetIntRange(FXObject*,FXSelector,void* ptr){
-  getRange(((FXint*)ptr)[0],((FXint*)ptr)[1]);
+  ((FXint*)ptr)[0]=range[0];
+  ((FXint*)ptr)[1]=range[1];
   return 1;
   }
 
 
 // Update range from a message
 long FXSlider::onCmdSetRealRange(FXObject*,FXSelector,void* ptr){
-  setRange((FXint) ((FXdouble*)ptr)[0],(FXint) ((FXdouble*)ptr)[1]);
+  setRange((FXint)((FXdouble*)ptr)[0],(FXint)((FXdouble*)ptr)[1]);
   return 1;
   }
 
@@ -395,7 +346,7 @@ long FXSlider::onLeftBtnPress(FXObject*,FXSelector,void* ptr){
 
 // Released Left button
 long FXSlider::onLeftBtnRelease(FXObject*,FXSelector,void* ptr){
-  FXuint flgs=flags;
+  register FXuint flgs=flags;
   if(isEnabled()){
     ungrab();
     getApp()->removeTimeout(this,ID_AUTOSLIDE);
@@ -526,7 +477,7 @@ long FXSlider::onMiddleBtnPress(FXObject*,FXSelector,void* ptr){
 
 // Released middle button
 long FXSlider::onMiddleBtnRelease(FXObject*,FXSelector,void* ptr){
-  FXuint flgs=flags;
+  register FXuint flgs=flags;
   if(isEnabled()){
     ungrab();
     getApp()->removeTimeout(this,ID_AUTOSLIDE);
@@ -544,6 +495,21 @@ long FXSlider::onMiddleBtnRelease(FXObject*,FXSelector,void* ptr){
   }
 
 
+// Mouse wheel
+long FXSlider::onMouseWheel(FXObject*,FXSelector,void* ptr){
+  register FXEvent *event=(FXEvent*)ptr;
+  register FXint p=pos+(event->code*incr)/120;
+  if(p<range[0]) p=range[0];
+  if(p>range[1]) p=range[1];
+  if(pos!=p){
+    setValue(p);
+    if(target) target->handle(this,FXSEL(SEL_CHANGED,message),(void*)(FXival)pos);
+    if(target) target->handle(this,FXSEL(SEL_COMMAND,message),(void*)(FXival)pos);
+    }
+  return 1;
+  }
+
+
 // The widget lost the grab for some reason
 long FXSlider::onUngrabbed(FXObject* sender,FXSelector sel,void* ptr){
   FXFrame::onUngrabbed(sender,sel,ptr);
@@ -580,13 +546,16 @@ long FXSlider::onAutoSlide(FXObject*,FXSelector,void* ptr){
 
 // Draw horizontal ticks
 void FXSlider::drawHorzTicks(FXDCWindow& dc,FXint,FXint y,FXint,FXint){
-  FXint v,d,p;
-  if(range[0]<range[1]){
+  register FXint interval=range[1]-range[0];
+  register FXint travel,offset,v,d,p;
+  if(0<interval){
     d=delta;
-    if(d==0) d=incr;
+    if(d<=0) d=incr;
     dc.setForeground(FXRGB(0,0,0));
+    travel=width-(border<<1)-padleft-padright-headsize-4;
+    offset=border+padleft+2+headsize/2;
     for(v=range[0]; v<=range[1]; v+=d){
-      p=headPos(v)+headsize/2;
+      p=offset+(travel*(v-range[0]))/interval;
       dc.fillRectangle(p,y,1,TICKSIZE);
       }
     }
@@ -595,13 +564,16 @@ void FXSlider::drawHorzTicks(FXDCWindow& dc,FXint,FXint y,FXint,FXint){
 
 // Draw vertical ticks
 void FXSlider::drawVertTicks(FXDCWindow& dc,FXint x,FXint,FXint,FXint){
-  FXint v,d,p;
-  if(range[0]<range[1]){
+  register FXint interval=range[1]-range[0];
+  register FXint travel,offset,v,d,p;
+  if(0<interval){
     d=delta;
-    if(d==0) d=incr;
+    if(d<=0) d=incr;
     dc.setForeground(FXRGB(0,0,0));
+    travel=height-(border<<1)-padtop-padbottom-headsize-4;
+    offset=height-border-padbottom-2-headsize/2;
     for(v=range[0]; v<=range[1]; v+=d){
-      p=headPos(v)+headsize/2;
+      p=offset-(travel*(v-range[0]))/interval;
       dc.fillRectangle(x,p,TICKSIZE,1);
       }
     }
@@ -708,7 +680,7 @@ long FXSlider::onPaint(FXObject*,FXSelector,void* ptr){
   FXint xx,yy,ww,hh;
   FXDCWindow dc(this,event);
 
-  // Paint background
+  // Repaint background
   dc.setForeground(backColor);
   dc.fillRectangle(0,0,width,height);
 
@@ -809,15 +781,14 @@ void FXSlider::setRange(FXint lo,FXint hi){
 // Also, the minimal amount is repainted, as one sometimes as very
 // large/wide sliders.
 void FXSlider::setValue(FXint p){
-  FXint travel,lo,hi,h;
+  register FXint interval=range[1]-range[0];
+  register FXint travel,lo,hi,h;
   if(p<range[0]) p=range[0];
   if(p>range[1]) p=range[1];
   if(options&SLIDER_VERTICAL){
     travel=height-(border<<1)-padtop-padbottom-headsize-4;
-    if(range[1]>range[0])
-      h=border+padtop+2+(travel*(range[1]-p))/(range[1]-range[0]);
-    else
-      h=border+padtop+2;
+    h=height-border-padbottom-2-headsize;
+    if(0<interval) h-=(travel*(p-range[0]))/interval;
     if(h!=headpos){
       FXMINMAX(lo,hi,headpos,h);
       headpos=h;
@@ -826,10 +797,8 @@ void FXSlider::setValue(FXint p){
     }
   else{
     travel=width-(border<<1)-padleft-padright-headsize-4;
-    if(range[1]>range[0])
-      h=border+padleft+2+(travel*(p-range[0]))/(range[1]-range[0]);
-    else
-      h=border+padleft+2;
+    h=border+padleft+2;
+    if(0<interval) h+=(travel*(p-range[0]))/interval;
     if(h!=headpos){
       FXMINMAX(lo,hi,headpos,h);
       headpos=h;
@@ -848,7 +817,7 @@ FXuint FXSlider::getSliderStyle() const {
 
 // Set slider options
 void FXSlider::setSliderStyle(FXuint style){
-  FXuint opts=(options&~SLIDER_MASK) | (style&SLIDER_MASK);
+  register FXuint opts=(options&~SLIDER_MASK) | (style&SLIDER_MASK);
   if(options!=opts){
     headsize=(opts&SLIDER_INSIDE_BAR)?HEADINSIDEBAR:HEADOVERHANGING;
     options=opts;
@@ -893,18 +862,6 @@ void FXSlider::setSlotColor(FXColor clr){
   }
 
 
-// Change help text
-void FXSlider::setHelpText(const FXString& text){
-  help=text;
-  }
-
-
-// Change tip text
-void FXSlider::setTipText(const FXString& text){
-  tip=text;
-  }
-
-
 // Change the delta between ticks
 void FXSlider::setTickDelta(FXint dist){
   if(dist<0) dist=0;
