@@ -3,7 +3,7 @@
 *                           S t r i n g   O b j e c t                           *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXString.cpp,v 1.113 2003/10/06 21:45:17 fox Exp $                       *
+* $Id: FXString.cpp,v 1.116 2004/04/21 20:58:37 fox Exp $                       *
 ********************************************************************************/
 #ifdef HAVE_VSSCANF
 #ifndef _GNU_SOURCE
@@ -184,7 +184,12 @@ FXString FXString::section(const FXchar* delim,FXint n,FXint start,FXint num) co
     while(s<len){
       c=str[s++];
       i=n;
-      while(--i>=0){ if(delim[i]==c && --start==0) goto a; }
+      while(--i>=0){
+        if(delim[i]==c){
+          if(--start==0) goto a;
+          break;
+          }
+        }
       }
     }
 a:e=s;
@@ -192,7 +197,12 @@ a:e=s;
     while(e<len){
       c=str[e];
       i=n;
-      while(--i>=0){ if(delim[i]==c && --num==0) goto b; }
+      while(--i>=0){
+        if(delim[i]==c){
+          if(--num) goto b; 
+          break;
+          }
+        }
       ++e;
       }
     }
@@ -313,10 +323,8 @@ FXString& FXString::assign(FXchar c,FXint n){
 
 // Assign first n characters of input string to this string
 FXString& FXString::assign(const FXchar* s,FXint n){
-  if(str!=s){
-    length(n);
-    memcpy(str,s,n);
-    }
+  length(n);
+  if(0<n){memmove(str,s,n);}
   return *this;
   }
 
