@@ -3,7 +3,7 @@
 *                   T o g g l e    B u t t o n    O b j e c t                   *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXToggleButton.cpp,v 1.46 2003/10/23 04:19:45 fox Exp $                  *
+* $Id: FXToggleButton.cpp,v 1.48 2004/02/08 17:29:07 fox Exp $                  *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -499,34 +499,35 @@ long FXToggleButton::onPaint(FXObject*,FXSelector,void* ptr){
 
   // Draw enabled state
   if(isEnabled()){
-    if(state && alticon)
+    if(state && alticon){
       dc.drawIcon(alticon,ix,iy);
-    else if(icon)
+      }
+    else if(icon){
       dc.drawIcon(icon,ix,iy);
+      }
     if(state && !altlabel.empty()){
       dc.setFont(font);
       dc.setForeground(textColor);
       drawLabel(dc,altlabel,althotoff,tx,ty,tw,th);
-      if(hasFocus()){
-        dc.drawFocusRectangle(border+1,border+1,width-2*border-2,height-2*border-2);
-        }
       }
     else if(!label.empty()){
       dc.setFont(font);
       dc.setForeground(textColor);
       drawLabel(dc,label,hotoff,tx,ty,tw,th);
-      if(hasFocus()){
-        dc.drawFocusRectangle(border+1,border+1,width-2*border-2,height-2*border-2);
-        }
+      }
+    if(hasFocus()){
+      dc.drawFocusRectangle(border+1,border+1,width-2*border-2,height-2*border-2);
       }
     }
 
   // Draw grayed-out state
   else{
-    if(state && alticon)
+    if(state && alticon){
       dc.drawIconSunken(alticon,ix,iy);
-    else if(icon)
+      }
+    else if(icon){
       dc.drawIconSunken(icon,ix,iy);
+      }
     if(state && !altlabel.empty()){
       dc.setFont(font);
       dc.setForeground(hiliteColor);
