@@ -3,7 +3,7 @@
 *                            V i s u a l   C l a s s                            *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1999,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1999,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,12 +19,12 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXVisual.cpp,v 1.61 2003/10/23 04:19:45 fox Exp $                        *
+* $Id: FXVisual.cpp,v 1.64 2004/02/18 16:37:50 fox Exp $                        *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
 #include "fxdefs.h"
-#include "fxkeys.h"
+#include "fxpriv.h"
 #include "FXStream.h"
 #include "FXString.h"
 #include "FXSize.h"
@@ -115,21 +115,21 @@ FXVisual::FXVisual(){
   flags=0;
   hint=1;
   depth=0;
-  info=NULL;
   numcolors=0;
   numred=0;
   numgreen=0;
   numblue=0;
   maxcolors=1000000;
   type=VISUALTYPE_UNKNOWN;
-#ifndef WIN32
-  visual=NULL;
+  info=NULL;
   colormap=0;
   freemap=FALSE;
+#ifndef WIN32
+  visual=NULL;
   gc=0;
   scrollgc=0;
 #else
-  hPalette=NULL;
+  pixelformat=0;
 #endif
   }
 
@@ -140,22 +140,20 @@ FXVisual::FXVisual(FXApp* a,FXuint flgs,FXuint d):FXId(a){
   flags=flgs;
   hint=FXMAX(1,d);
   depth=0;
-  info=NULL;
   numcolors=0;
   numred=0;
   numgreen=0;
   numblue=0;
   maxcolors=1000000;
   type=VISUALTYPE_UNKNOWN;
-#ifndef WIN32
-  visual=NULL;
+  info=NULL;
   colormap=0;
   freemap=FALSE;
+#ifndef WIN32
+  visual=NULL;
   gc=0;
   scrollgc=0;
 #else
-  hPalette=NULL;
-  info=NULL;
   pixelformat=0;
 #endif
   }
@@ -196,41 +194,6 @@ static FXuint gamma_adjust(FXdouble gamma,FXuint value,FXuint max){
 static inline double fxabs(double a){ return a<0 ? -a : a; }
 
 
-// Make GC for this visual
-void* FXVisual::makegc(FXbool gex){
-  XGCValues gval;
-  FXID drawable;
-  GC gg;
-
-  gval.fill_style=FillSolid;
-  gval.graphics_exposures=gex;
-
-  // Monochrome gc; create a temporary pixmap of depth 1
-  if(flags&VISUAL_MONOCHROME){
-    FXTRACE((150,"%s::create: gc for monochrome pixmap\n",getClassName()));
-    drawable=XCreatePixmap(DISPLAY(getApp()),XDefaultRootWindow(DISPLAY(getApp())),1,1,1);
-    gg=XCreateGC(DISPLAY(getApp()),drawable,GCFillStyle|GCGraphicsExposures,&gval);
-    XFreePixmap(DISPLAY(getApp()),drawable);
-    }
-
-  // For default visual; this is easy as we already have a matching window
-  else if(visual==DefaultVisual(DISPLAY(getApp()),DefaultScreen(DISPLAY(getApp())))){
-    FXTRACE((150,"%s::create: gc for default visual\n",getClassName()));
-    gg=XCreateGC(DISPLAY(getApp()),XDefaultRootWindow(DISPLAY(getApp())),GCFillStyle|GCGraphicsExposures,&gval);
-    }
-
-  // For arbitrary visual; create a temporary pixmap of the same depth as the visual
-  else{
-    FXTRACE((150,"%s::create: gc for non-default visual\n",getClassName()));
-    drawable=XCreatePixmap(DISPLAY(getApp()),XDefaultRootWindow(DISPLAY(getApp())),1,1,depth);
-    gg=XCreateGC(DISPLAY(getApp()),drawable,GCFillStyle|GCGraphicsExposures,&gval);
-    XFreePixmap(DISPLAY(getApp()),drawable);
-    }
-
-  return gg;
-  }
-
-
 // Setup for true color
 void FXVisual::setuptruecolor(){
   register FXuint  redshift,greenshift,blueshift;
@@ -975,6 +938,8 @@ static HPALETTE createAllPurposePalette(HDC hdc){
 
   // Create palette and we're done
   hPalette=CreatePalette((const LOGPALETTE*)&palette);
+
+  // Return palette
   return hPalette;
   }
 
@@ -1089,8 +1054,8 @@ void FXVisual::create(){
       setupcolormap();
 
       // Make GC's for this visual
-      gc=makegc(FALSE);
-      scrollgc=makegc(TRUE);
+      gc=fxmakegc(DISPLAY(getApp()),(Visual*)visual,depth,FALSE);
+      scrollgc=fxmakegc(DISPLAY(getApp()),(Visual*)visual,depth,TRUE);
 
       xid=1;
 #else
@@ -1105,13 +1070,14 @@ void FXVisual::create(){
 
       // Check for palette mode; assume 8-bit for now
       if(GetDeviceCaps(hdc,RASTERCAPS)&RC_PALETTE){
-        hPalette=createAllPurposePalette(hdc);     // FIXME how about 4-bit VGA mode?
+        colormap=createAllPurposePalette(hdc);     // FIXME how about 4-bit VGA mode?
         depth=8;
         numred=6;               // We have a 6x6x6 ramp, at least...
         numgreen=6;
         numblue=6;
         numcolors=256;
         type=VISUALTYPE_INDEX;
+        freemap=TRUE;
         }
 
       // True color mode; find out how deep
@@ -1168,6 +1134,8 @@ void FXVisual::create(){
 void FXVisual::detach(){
   if(xid){
     FXTRACE((100,"%s::detach %p\n",getClassName(),this));
+    colormap=0;
+    freemap=FALSE;
     xid=0;
     }
   }
@@ -1179,14 +1147,14 @@ void FXVisual::destroy(){
     if(getApp()->isInitialized()){
       FXTRACE((100,"%s::destroy %p\n",getClassName(),this));
 #ifndef WIN32
-      if(freemap){ XFreeColormap(DISPLAY(getApp()),colormap); }
+      if(freemap){XFreeColormap(DISPLAY(getApp()),colormap);}
       XFreeGC(DISPLAY(getApp()),(GC)gc);
       XFreeGC(DISPLAY(getApp()),(GC)scrollgc);
-      freemap=FALSE;
 #else
-      if(hPalette){ DeleteObject(hPalette); }
-      hPalette=NULL;
+      if(freemap){DeleteObject((HPALETTE)colormap);}
 #endif
+      colormap=0;
+      freemap=FALSE;
       }
     xid=0;
     }
