@@ -5,7 +5,7 @@
 *********************************************************************************
 * Copyright (C) 2000 by Jeroen van der Zijp.   All Rights Reserved.             *
 *********************************************************************************
-* $Id: imageviewer.cpp,v 1.99 2003/08/26 23:08:50 fox Exp $                     *
+* $Id: imageviewer.cpp,v 1.103 2004/04/28 16:29:07 fox Exp $                    *
 ********************************************************************************/
 #include "fx.h"
 #ifdef HAVE_PNG_H
@@ -20,6 +20,7 @@
 #include "FXICOImage.h"
 #include "FXTGAImage.h"
 #include "FXRGBImage.h"
+#include "FXPPMImage.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <sys/stat.h>
@@ -89,6 +90,7 @@ public:
     ID_ROTATE_270,
     ID_MIRROR_HOR,
     ID_MIRROR_VER,
+    ID_MIRROR_BOTH,
     ID_SCALE,
     ID_CROP,
     ID_LAST
@@ -197,6 +199,7 @@ const FXchar patterns[]=
   "\nRGB Image  (*.rgb)"
   "\nXBM Image  (*.xbm)"
   "\nTARGA Image  (*.tga)"
+  "\nPPM Image  (*.ppm)"
 #ifdef HAVE_PNG_H
   "\nPNG Image  (*.png)"
 #endif
@@ -226,6 +229,7 @@ FXDEFMAP(ImageWindow) ImageWindowMap[]={
   FXMAPFUNC(SEL_COMMAND,       ImageWindow::ID_ROTATE_270, ImageWindow::onCmdRotate),
   FXMAPFUNC(SEL_COMMAND,       ImageWindow::ID_MIRROR_HOR, ImageWindow::onCmdMirror),
   FXMAPFUNC(SEL_COMMAND,       ImageWindow::ID_MIRROR_VER, ImageWindow::onCmdMirror),
+  FXMAPFUNC(SEL_COMMAND,       ImageWindow::ID_MIRROR_BOTH,ImageWindow::onCmdMirror),
   FXMAPFUNC(SEL_COMMAND,       ImageWindow::ID_SCALE,      ImageWindow::onCmdScale),
   FXMAPFUNC(SEL_COMMAND,       ImageWindow::ID_CROP,       ImageWindow::onCmdCrop),
   FXMAPFUNC(SEL_UPDATE,        ImageWindow::ID_ROTATE_90,  ImageWindow::onUpdImage),
@@ -233,6 +237,7 @@ FXDEFMAP(ImageWindow) ImageWindowMap[]={
   FXMAPFUNC(SEL_UPDATE,        ImageWindow::ID_ROTATE_270, ImageWindow::onUpdImage),
   FXMAPFUNC(SEL_UPDATE,        ImageWindow::ID_MIRROR_HOR, ImageWindow::onUpdImage),
   FXMAPFUNC(SEL_UPDATE,        ImageWindow::ID_MIRROR_VER, ImageWindow::onUpdImage),
+  FXMAPFUNC(SEL_UPDATE,        ImageWindow::ID_MIRROR_BOTH,ImageWindow::onUpdImage),
   FXMAPFUNC(SEL_UPDATE,        ImageWindow::ID_SCALE,      ImageWindow::onUpdImage),
   FXMAPFUNC(SEL_UPDATE,        ImageWindow::ID_CROP,       ImageWindow::onUpdImage),
   };
@@ -366,8 +371,9 @@ ImageWindow::ImageWindow(FXApp* a):FXMainWindow(a,"FOX Image Viewer: - untitled"
   new FXMenuCommand(manipmenu,"Rotate 90\t\tRotate 90 degrees.",NULL,this,ID_ROTATE_90);
   new FXMenuCommand(manipmenu,"Rotate 180\t\tRotate 180 degrees.",NULL,this,ID_ROTATE_180);
   new FXMenuCommand(manipmenu,"Rotate -90\t\tRotate -90 degrees.",NULL,this,ID_ROTATE_270);
-  new FXMenuCommand(manipmenu,"Mirror Hor.\t\tMirror Horizontally.",NULL,this,ID_MIRROR_HOR);
-  new FXMenuCommand(manipmenu,"Mirror Ver.\t\tMirror Vertically.",NULL,this,ID_MIRROR_VER);
+  new FXMenuCommand(manipmenu,"Mirror Horizontally\t\tMirror Horizontally.",NULL,this,ID_MIRROR_HOR);
+  new FXMenuCommand(manipmenu,"Mirror Vertically\t\tMirror Vertically.",NULL,this,ID_MIRROR_VER);
+  new FXMenuCommand(manipmenu,"Mirror Both\t\tMirror Both.",NULL,this,ID_MIRROR_BOTH);
   new FXMenuCommand(manipmenu,"Scale...\t\tScale image.",NULL,this,ID_SCALE);
   new FXMenuCommand(manipmenu,"Crop...\t\tCrop image.",NULL,this,ID_CROP);
 
@@ -423,7 +429,7 @@ ImageWindow::~ImageWindow(){
 
 // About box
 long ImageWindow::onCmdAbout(FXObject*,FXSelector,void*){
-  FXMessageBox about(this,"About Image Viewer","Image Viewer demonstrates the FOX ImageView widget.\n\nUsing the FOX C++ GUI Library (http://www.fox-toolkit.org)\n\nCopyright (C) 2000,2001 Jeroen van der Zijp (jeroen@fox-toolkit.org)",NULL,MBOX_OK|DECOR_TITLE|DECOR_BORDER);
+  FXMessageBox about(this,"About Image Viewer","Image Viewer demonstrates the FOX ImageView widget.\n\nUsing the FOX C++ GUI Library (http://www.fox-toolkit.org)\n\nCopyright (C) 2000,2004 Jeroen van der Zijp (jeroen@fox-toolkit.org)",NULL,MBOX_OK|DECOR_TITLE|DECOR_BORDER);
   about.execute();
   return 1;
   }
@@ -446,7 +452,7 @@ FXbool ImageWindow::loadimage(const FXString& file){
   else if(comparecase(ext,"pcx")==0){
     img=new FXPCXImage(getApp(),NULL,IMAGE_KEEP|IMAGE_SHMI|IMAGE_SHMP);
     }
-  else if(comparecase(ext,"ico")==0){
+  else if(comparecase(ext,"ico")==0 || comparecase(ext,"cur")==0){
     img=new FXICOImage(getApp(),NULL,IMAGE_KEEP|IMAGE_SHMI|IMAGE_SHMP);
     }
   else if(comparecase(ext,"tga")==0){
@@ -458,6 +464,9 @@ FXbool ImageWindow::loadimage(const FXString& file){
   else if(comparecase(ext,"xbm")==0){
     img=new FXXBMImage(getApp(),NULL,NULL,IMAGE_KEEP|IMAGE_SHMI|IMAGE_SHMP);
     }
+  else if(comparecase(ext,"ppm")==0){
+    img=new FXPPMImage(getApp(),NULL,IMAGE_KEEP|IMAGE_SHMI|IMAGE_SHMP);
+    }
 #ifdef HAVE_PNG_H
   else if(comparecase(ext,"png")==0){
     img=new FXPNGImage(getApp(),NULL,IMAGE_KEEP|IMAGE_SHMI|IMAGE_SHMP);
@@ -602,7 +611,7 @@ long ImageWindow::onCmdRecentFile(FXObject*,FXSelector,void* ptr){
 
 // Command from the tree list
 long ImageWindow::onCmdFileList(FXObject*,FXSelector,void* ptr){
-  FXint index=(FXint)(long)ptr;
+  FXint index=(FXint)(FXival)ptr;
   if(0<=index){
     if(filelist->isItemDirectory(index)){
       filelist->setDirectory(filelist->getItemPathname(index));
@@ -648,6 +657,7 @@ long ImageWindow::onCmdMirror(FXObject*,FXSelector sel,void*){
   switch(FXSELID(sel)){
     case ID_MIRROR_HOR: image->mirror(TRUE,FALSE); break;
     case ID_MIRROR_VER: image->mirror(FALSE,TRUE); break;
+    case ID_MIRROR_BOTH: image->mirror(TRUE,TRUE); break;
     }
   imageview->setImage(image);
   return 1;
