@@ -3,7 +3,7 @@
 *                R e s o u r c e   W r a p p i n g   U t i l i t y              *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This program is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU General Public License as published by          *
@@ -19,10 +19,13 @@
 * along with this program; if not, write to the Free Software                   *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: reswrap.cpp,v 1.9 2003/08/26 23:08:50 fox Exp $                          *
+* $Id: reswrap.cpp,v 1.11 2004/02/25 14:28:45 fox Exp $                         *
 ********************************************************************************/
-#include "xincs.h"
-#include "fxdefs.h"
+#include "stdio.h"
+#include "stdlib.h"
+#include "string.h"
+#include "ctype.h"
+
 
 
 #define MODE_DECIMAL  0
@@ -47,7 +50,7 @@
 
 */
 
-const char version[]="3.0.0";
+const char version[]="3.1.0";
 
 
 
@@ -72,6 +75,7 @@ void printusage(){
   fprintf(stderr,"  -p prefix      Place prefix in front of names of declarations and definitions\n");
   fprintf(stderr,"  -n namespace   Place declarations and definitions inside given namespace\n");
   fprintf(stderr,"  -c cols        Change number of columns in output to cols\n");
+  fprintf(stderr,"  -u             Force unsigned char even for text mode\n");
   fprintf(stderr,"\n");
   fprintf(stderr,"Each file may be preceded by the following extra option:\n");
   fprintf(stderr,"  -r name        Override resource name of following resource file\n");
@@ -82,7 +86,7 @@ void printusage(){
 /* Print version information */
 void printversion(){
   fprintf(stderr,"Reswrap %s %s.\n",version,__DATE__);
-  fprintf(stderr,"Copyright (C) 1997,2003 Jeroen van der Zijp. All Rights Reserved.\n");
+  fprintf(stderr,"Copyright (C) 1997,2004 Jeroen van der Zijp. All Rights Reserved.\n");
   fprintf(stderr,"Please visit: http://www.fox-toolkit.org for further information.\n");
   fprintf(stderr,"\n");
   fprintf(stderr,"This program is free software; you can redistribute it and/or modify\n");
@@ -105,7 +109,7 @@ void printversion(){
 int main(int argc,char **argv){
   char *outfilename,*resfilename,*ptr;
   FILE *resfile,*outfile;
-  int i,fm,to,cc,b,first,col,append,maxcols,external,header,override,include,mode,colsset,ascii,msdos,keepext,hex;
+  int i,fm,to,cc,b,first,col,append,maxcols,external,header,override,include,mode,colsset,ascii,msdos,keepext,hex,forceunsigned;
   const char *thenamespace,*theprefix;
   char resname[100];
 
@@ -125,6 +129,7 @@ int main(int argc,char **argv){
   thenamespace=0;
   theprefix="";
   append=0;
+  forceunsigned=0;
 
   /* Check arguments */
   if(argc<2){
@@ -182,6 +187,11 @@ int main(int argc,char **argv){
       header=0;
       }
 
+    /* Force unsigned */
+    else if(argv[i][1]=='u'){
+      forceunsigned=1;
+      }
+
     /* Generate as external reference */
     else if(argv[i][1]=='e'){
       external=1;
@@ -334,8 +344,15 @@ int main(int argc,char **argv){
     /* Generate external reference for #include's */
     if(external){ fprintf(outfile,"extern "); }
 
-    /* Output declaration and prefix */
-    fprintf(outfile,"const unsigned char %s%s[]",theprefix,resname);
+    /* In text mode, output a 'char' declaration */
+    if((mode==MODE_TEXT) && !forceunsigned){
+      fprintf(outfile,"const char %s%s[]",theprefix,resname);
+      }
+     
+    /* In binary mode, output a 'unsigned char' declaration */
+    else{
+      fprintf(outfile,"const unsigned char %s%s[]",theprefix,resname);
+      }
 
     /* Generate resource array */
     if(!include){
